==> help-2.0.0.tgz: package/index.js <==
// src-v2.js

const {table} = require("table")
const fs = require("fs")
const path = require("path")
const caller = require("caller-path")


let regex = [
	/(?<=this\.).+?(?=\=)/,
	/(?<=function).+?(?=\()/
]

let simple = true

function help(name) {

	if (!name) name = this.constructor.name
	if (name == "Function") name = this.name

	let filename = module.parent.filename
	let file = fs.readFileSync(filename, "utf8")


	// get matches
	let matches = file.match(/(?<=\/\/!).+(.|\n).+/mgi)
	if (!matches) {
		console.log("no tagged methods found!\nplease add a comment [//] with an [!] above the methods you want to highlight:\n\n//! description of your method")
		return []
	}

	// parse matches
	let parsed = matches.map(x => {
		x = x.replace("\t","").split("\n")

		let line1 = x[0].trim() || undefined
		let line2 = x[1]
		if (!line2) line2 = ""
		let output = {line1, line2}
		return output
	})



	let methods = parsed.map(match => {
			
		// if (match.length !== 2) return
		let description_raw = match.line1
		let code = match.line2
		let name, description, type, args, isFunction

		if (code.match(/async|function|=>|\(/gi)) isFunction = true

		// get name
		regex.forEach(re => {
			let fnMatch = code.match(re)
			if (fnMatch) name = fnMatch[0].trim()
		})

		// get variables
		let argsMatch = code.match(/(?<=\().+?(?=\))/g)
		if (argsMatch) {
			args = argsMatch[0].split(",")
		} else args = []

		// get async or sync 
		if (code.includes("async")) type = "async"
		else type = undefined

		// no description
		if (!description_raw) description = "[NO DESCRIPTION]"
		else description = description_raw.trim()

		if (isFunction) name = `.${name}()`


		let output = {name, description, type, args}

		return output
	})

	methods = methods.filter(x => x.name)



	let title = `METHOD HELP\nhere are the methods of "${name}"\n/${path.parse(filename).base}`
	let headers, list
	if (simple) {
		headers = ["NAME", "DESCRIPTION"]
		list = methods.map(x => [x.name, x.description])
	} else {
		headers = ["NAME", "DESCRIPTION" ,"TYPE", "ARGS"]
		list = methods.map(x => [x.name, x.description, (x.type) ? x.type : "", x.args])
	}

	list.unshift(headers)



	let tableConfig = {
		header: {
			alignment: "center",
			content: title,
			wrapWord: true
		},
		columns: [
			{ alignment: "left", },
			{ alignment: "left", wrapWord: true},
			{ alignment: "center" },
			{ alignment: "left" },
		],
	}

	let output = table(list, tableConfig)
	console.log(output)
	return methods

}





module.exports = help

==> help-2.1.0.tgz: package/index.js <==
// src-v2.js

const fs = require("fs")
const path = require("path")
const caller = require("caller-path")


let regex = [
	/(?<=this\.).+?(?=\=)/,
	/(?<=function).+?(?=\()/
]

let simple = true

function help(name) {

	if (!name) name = this.constructor.name
	if (name == "Function") name = this.name

	let filename = module.parent.filename
	let file = fs.readFileSync(filename, "utf8")


	// get matches
	let matches = file.match(/(?<=\/\/!).+(.|\n).+/mgi)
	if (!matches) {
		console.log("no tagged methods found!\nplease add a comment [//] with an [!] above the methods you want to highlight:\n\n//! description of your method")
		return []
	}

	// parse matches
	let parsed = matches.map(x => {
		x = x.replace("\t","").split("\n")

		let line1 = x[0].trim() || undefined
		let line2 = x[1]
		if (!line2) line2 = ""
		let output = {line1, line2}
		return output
	})



	let methods = parsed.map(match => {
			
		// if (match.length !== 2) return
		let description_raw = match.line1
		let code = match.line2
		let name, description, type, args, isFunction

		if (code.match(/async|function|=>|\(/gi)) isFunction = true

		// get name
		regex.forEach(re => {
			let fnMatch = code.match(re)
			if (fnMatch) name = fnMatch[0].trim()
		})

		// get variables
		let argsMatch = code.match(/(?<=\().+?(?=\))/g)
		if (argsMatch) {
			args = argsMatch[0].split(",")
		} else args = []

		// get async or sync 
		if (code.includes("async")) type = "async"
		else type = undefined

		// no description
		if (!description_raw) description = "[NO DESCRIPTION]"
		else description = description_raw.trim()

		if (isFunction) name = `.${name}()`


		let output = {name, description, type, args}

		return output
	})

	methods = methods.filter(x => x.name)


	let title = `"${name.toUpperCase()}" METHODS HELP`
	let description = `from /${path.parse(filename).base}`
	let headers, list
	if (simple) {
		headers = ["NAME", "DESCRIPTION"]
		list = methods.map(x => [x.name, x.description])
	} else {
		headers = ["NAME", "DESCRIPTION" ,"TYPE", "ARGS"]
		list = methods.map(x => [x.name, x.description, (x.type) ? x.type : "", x.args])
	}

	let lengths = list.map(x => x[0].length)
	let pad = Math.max(...lengths)
	let columns = process.stdout.columns
	let div = "-".repeat(columns)
	if (!columns) div = ""


	// output to console
	console.log(title)
	console.log(description)
	console.log(div)
	console.log(list.map(x => `${x[0].padEnd(pad)} | ${x[1]}`).join("\n"))
	console.log(div)

	return methods

}





module.exports = help
